bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 38. Aventiure
___________________________________________________ #### Wie hern Dietriches <man> alle erslagen wrden
| ### o hort man allenthalben iamer also groz ### daz palas vn– tvrne von dem wuof erdoz ### do hort ez och von Berne ein Dietriches man ### dvrch disev starchen mere wie balde er gahen began [88b]
###### 2173 | ### Do sprach er zvo dem fvrsten hoert min her Dietrich ### swaz ich noch her <gelebt> han so rehte vnmvgelich ### gehort ich klagen nie mere als ich nv han vernomen ### ich wene der kvnich selbe ist zvo der hohgezite chomen
###### 2174 | ### Wie mehtens anders alle haben solhe not ### der kvnich do Kriemh' ir einez daz ist tot ### von den chvenen gesten dvrch ir nit gelegen ### ez wæinet vngefvoge vil manich zierlicher degen
###### 2175 | ### Do sprach der vogt von Berne mine vil liebe man ### nv gahet niht ze sere swaz hie hant getan ### die ellenden reken des gat in michel not ### vn– lat si des geniezen daz ich in minen fride enbot
###### 2176 | ### Do sprach der chvene Wolfhart ich wil dar gan ### vn– wil der mere vragen was si hant getan ### vnd wilz iv sagen denne vil lieber herre min ### als ichs dort ervinde waz div klage mvge sin
###### 2177 | ### Do sprach der herre Dietrich swa man zorns sih versiht ### ob vngefvegiv vrage danne da geschiht ### daz betrvebet reken lihte ir mvot ### ichen wil niht Wolfhart daz ir die vrage tvot
###### 2178 | ### Do bat Helpfriche balde dar gan ### vnd hiez daz ervinden an Ezeln man ### oder an den gesten waz mere da geschehen ### do het man von livten so grozen iamer nie gesehen
###### 2179 | ### Der bote begvnde vragen waz ist hie getan ### do sprach æiner drvnder da ist vil gar zergan ### swaz wir frveden heten in der Hevnen lant ### hie ligt erslagen Rvedeger von der Bvrgonde hant
###### 2180 | ### Die mit im dar in chomen der ist einer niht genesen ### do enchvnde Helpfriche nimmer leider wesen ### ia gehoert <er> mere so rehte vngerne nie ### der bote ze Dietriche vil sere wainende gie
###### 2181 | ### Waz hapt ir vns erfvnden sprach do Dietrich ### wie wæinet ir so sere degen Helpfrich ### do sprach der edel reke ich mag wol balde klagen ### den gvoten Rvedegere hant die Bvrgonde erslagen
###### 2182 | ### Do sprach der helt von Berne des sol niht wellen got ### daz wer ein starchiv rach vn– och des tievels spot ### wa mit het Rvedeger an in daz versolt ### ia ist mir daz wol chvnt er ist den ellenden holt
###### 2183 | ### Dez antwurte Wolfhart vnd heten siz getan ### so solt ez in allen an daz leben gan ### ob wir inz vertrvegen des wer wir geschant ### ia hat vns vil gedienet des gvoten Rvedegeres hant
###### 2184 | ### Der vogt der Amelvnge hiez ervarn baz ### vil harte seneliche er in ein venster saz ### do bat er Hilprande zvo den gesten gan ### daz er an in erfvere waz da wer getan
###### 2185 | ### Der stvrmchvene reke maister Hilprant ### weder shilt noch waffen trvog er an der hant [89a] ### er wolde in sinen zvhten zvo den gesten gan ### von siner swester chinde wart im ein strafen getan
###### 2186 | ### Do sprach der grimme Wolfhart vn– welt ir dar blozer gan ### so mag ez an ein schelten nimmer wol gestan ### so mvezet ir lesterliche tvon die widervart ### choemt ir dar gewafent daz ir eteslicher wol bewart
###### 2187 | ### Do garte sich der wise dvrch des tvmben rat ### e daz ers inne wurde do warn in ir wat ### alle Dietriches reken vn– trvogen swert ein der hant ### dem helde waz ez leide vil gerne het erz erwant
###### 2188 | ### Er vragte war si wolden wir wellen mit iv dar ### waz ob von Tronge Hagene deste wirs getar ### gein iv mit spotte sprechen des er wol chan gephlegen ### do er daz gehorte do gestvont inz der degen
###### 2189 | ### Nv sach der chvene Volker wol gewaffent gan ### die reken von Berne die Dietriches man ### begvrtet mit den swerten si trvogen shilt enhant ### er sagt ez sinen herren vzer Bvrgonde lant
###### 2190 | ### Do sprach der videlere ich sihe dort her gan ### so rehte veintliche die Dietriches man ### gewafent vnder helme si wellent vns bestan ### ich wen ez an daz vbel vns ellenden welle gan
###### 2191 | ### In den selben ziten chom och Hildeprant ### do satzter fvr die fveze sines schildes rant ### er begvnde fragen die Gvnthers man ### owe ir gvote helde waz het iv Rvedeger getan
###### 2192 | ### Mich hat min her Dietrich her zvo iv gesant ### ob erslagen hete iwer deheines hant ### den edeln marchgraven als vns daz ist geseit ### wir chvnnen niht vberwinden div vil grozlichen leit
###### 2193 | ### Do sprach von Tronge Hagne daz mer ist vngelogen ### wie wol ich iv des gvnde het iv der bote betrogen ### dvrch Rvedegeres liebe daz lebte noch sin lip ### den immer mvegen wæinen bæidev man vn– wip
###### 2194 | ### Do si daz reht erhorten daz er wære tot ### do klagten in die reken ir triwe in daz gebot ### den <Dietriches> reken den sach man trehne gan ### vber bart vn– vber chinne in was vil læit getan
###### 2195 | ### Der herzoge vzer Berne Sigestap do sprach ### nv hat gar æin ende genomen der gemach ### den vns hie fvogtte Rvedeger nah vnsern læiden tagen ### frovde ellender diete lit von iv helden hie erslagen
###### 2196 | ### Do sprach von Amelvnge der degen Wolfwin ### vnd ob ich hivte sehe tot den vater min ### mir enwurde nimmer leider denn vmbe sinen lip ### owe wer sol nv troesten des gvoten marchgraven wip
###### 2197 | ### Do sprach in zorns mvote der degen Wolfhart ### wer wiset nv die reken so manige hervart ### also der marchgrave vil dike hat getan ### owe vil edel Rvedeger daz wir dich svs vlorn han [89b]
###### 2198 | ### Wolfbrant vn– Helfrich vn– ovch Helmnot ### mit allen irn frivnden si wæinten sinen tot ### vor sivften mohte vragen niht der mere Hilprant ### er sprach nv tvot ir degene dar nach min herre her hat gesant
###### 2199 | ### Gebt vns Rvedegern also toten vz dem sal ### an dem gar mit iamer lit vnser frovden val ### vn– lat vns an im dienen daz er ie hat getan ### an vns vil groze triwe vn– an ander manigen man
###### 2200 | ### Wir sin ovch ellende also Rvedeger der degen ### wes <lazet> ir vns biten lat in vns after wegen ### <tragen> daz wir nach tode loenen noh dem man ### wir heten ez vil billich bi sinem lebene getan
###### 2201 | ### Do sprach der kvnich Gvnther nie dienst wart so gvot ### so den ein frivnt frivnde nach dem tode tvot ### daz hiez ich stete triwe swer die kan began ### ir loenet im von schvlden er hat iv liebe getan
###### 2202 | ### Wie lange svl wir flegen sprach Wolfhart der degen ### sit vnser trost der beste von iv ist tot gelegen ### vn– wir sin læider mere megen niht gehaben ### lat vn sin tragen hinne da wir den reken begraben
###### 2203 | ### Des antwurte im Volker niemen iv in git ### nv nemt in in dem sale da der degen lit ### mit starch wunden gevallen in daz blvot ### so ist ez ein voller dienst den ir hie Rvedegere tvot
###### 2204 | ### Do sprach der chvene Wolfhart got weiz wol her spilman ### ir dvrft vns niht raitzen ir hapt vns vbel getan ### trost ich vor minem herren so chomet irs in not ### des mveze wirz lazen wan er vns striten hie verbot
###### 2205 | ### Do sprach der videlere der vorht ist alle ze vil ### swaz man im verbivtet ders allez lazzen wil ### daz chan ich niht geheizen rehtes heldes mvot ### die rede dvhte Hagen von sinem hergesellen gvot
###### 2206 | ### Dez lat iv niht gelangen sprach aber Wolfhart ### ich entrihte iv so die saiten swenn ir die widervart ### ritet gein Rine daz irs wol mvget sagen ### iwer vbermvote mag ich mit eren niht vertragen
###### 2207 | ### Do sprach der videlere swenne ir die sæiten min ### verirret gvoter doene der iwers helm schin ### mvoz vil trvebe werden von der minen hant ### swie aber ich gerite in der Bvrgonde lant
###### 2208 | ### Do wolt er zvo im springen wan daz in niht enlie ### Hildebrant sin oechæim in vaste ze im gevie ### ich wene dv woldest wueten dvrch dinen tvmben zorn ### mines herzen hvlde dv hætest immer mer verlorn
###### 2209 | ### Lat ab den lewen maister er ist so grimme gemvot ### chvmt er mir zen handen sprach Volker der degen gvot ### het ir die werlt alle mit siner hant erslagen ### ich slahe in daz erz wider nimmer mere darf gesagen
###### 2210 | ### Des wart vil sere erzvrnet der Bernære mvot ### den shilt gervchte Wolfhart ein sneller helt gvot [90a] ### alsam ein lewe wide lief er vor in dan ### im wart ein gehez volgen von sinen frivnden getan
###### 2211 | ### Swie weiter sprvnge er pflege fvr des sales want ### doch ergaht in vor der stiege der alte Hildebrant ### er wolt in vor im niht lazen chomen in den strit ### si fvnden daz si svochten an den ellenden sit
###### 2212 | ### Do sprach zvo Hagen maister Hilbrant ### div swert man hoert erklingen an ir bæider hant ### si waren sere erzvrnet daz moeht man chiesen sint ### von ir zwaier swerte gie der fivr rote wint
###### 2213 | ### Die wurden do gescheiden in des strites not ### daz taten die von Berne als in ir chraft gebot ### zehant do maister Hildebrant want von Hagen dan ### do lief der starche Wolfhart den chvenen Volkern an
###### 2214 | ### Er slvoch den videlere vf den helme gvot ### daz des swertes ecke vntz vf die spange wuot ### daz vergalt mit ellen der chvene spileman ### do slvoch Wolfharten daz er stieben began
###### 2215 | ### Dez fivrs vz den ringen hiwuen si genvoch ### haz ir islicher dem andern trvoch ### die shiet do von Berne der degen Wolfwin ### ob ez ein helt niht were daz chvnde nimmer gesin
| ### Gvnther der degen mit vil williger hant ### enphie die helde mere von Amelvnge lant ### Giselher der herre die liehten helm vaz ### der frvmt er da vil manigez von blvote rot vn– naz
###### 2217 | ### Danchwart Hagen brvoder waz ein grimmich man ### swaz er da vor in strite hete getan ### den Ezeln reken daz waz gar ein wint ### nv vaht vil tobliche des chvenen Aldrianes chint
###### 2218 | ### Ritschart vn– Gerbart Helpfrich vn– Wicharat ### die heten in manigen stvrm selten sich gespart ### des brahten si wol inne die Gvntheres man ### do sach man Wolfprande in strite herlichen gan
###### 2219 | ### Do vaht alsam er wuote der alte Hildebrant ### vil der gvoten recken vor Wolfhartes hant ### mit tode mvose vallen von swerten in daz blvot ### svs rachen Rvedegern die reken chvene vnde gvot
###### 2220 | ### Do vaht der herre Sigstap als im sin ellen riet ### hei waz er im dem strite der gvoten helm vershriet ### den sinen veinden Dietriches swester svn ### er chvnde in dem stvrme nimmer bezzers niht getvon
###### 2221 | ### Volker der starche do er daz ersach ### daz Sigestap der chvene den blvotigen wach ### hei vz herten ringen daz waz dem helde zorn ### er sprach im hin engegne do hete Sigestap verlorn
###### 2222 | ### von dem videlere vil schiere daz leben ### er begvnde im siner chvnste al solhen teil da geben ### daz er von sinem swerte mvose ligen tot ### daz rach der alte Hildebrant als im sin ellen daz gebot [90b]
###### 2223 | ### Owe liebes herren sprach maister Hildebrant ### der hie leit erstorben vor Volkers hant ### nvne sol der videlere lenger niht genesen ### Hildebrant der chvene wie chvnde er grimmiger sin gewesen
###### 2224 | ### Do slvog er Volkern daz im div helmbant ### stvben allenthalben zvo des salez want ### von helm vn– och von schilte den chvenen spileman ### da von der starche Volker do den ende da gewan
###### 2225 | ### Do drvngen zvo dem strite die Dietriches man ### si slvogen daz die ringe vil verre dreten dan ### vnt daz man ort der swerte vil hohe fliegen sach ### si holten vz den helmen den heiz fliezenden bach
###### 2226 | ### Do sach von Tronge Hagen Volkern tot ### daz waz zer hochgezite sin aller groestiv not ### die er da het gewunnen an mag vn– och an man ### owe wie harte Hagen den helt do reken began
###### 2227 | ### Nv en sol sin niht geniezen der alte Hildebrant ### min helfe lit erslagen von des heldes hant ### der beste hergeselle den ich ie gewan ### den schilt den rvchter hoher do gie er howende dan
###### 2228 | ### Helpfrich der starcke Danchwarten slvoch ### Gvnther vn– Giselher den waz ez leid genvoch ### do si in vallen sahen in der starchen not ### er het mit sinen handen wol vergolten sinen tot
| ### Die wile gie och Wolfhart beidiv wider vn– dan ### allez howende die Gvntheres man ### er waz die driten chere nv chomen dvrch daz wal ### da viel vor sinen handen vil manich reke zetal
###### 2230 | ### Do rief der herre Giselher Wolfharten an ### owe daz ich so grimmen veint ie gewan ### edel riter chvene nv wendet gein in ### ich wil ez helfen enden ez mak niht anders gesin
###### 2231 | ### Ze Giselher cherte Wolfhart in den strit ### do slvoch ir ietweder vil manige wunden wit ### so rehte chreftichliche er zvo dem chunige dranch ### daz imz blvot vndern fvezen al vbers hovbet spranch
###### 2232 | ### Mit swinden slegen grimme der shoenen voten kint ### enphie Wolfharten den chvenen helt sint ### swie starcke der degen were er chvnde niht genesen ### ezn dorft chvnich so ivnger nimmer chvener sin gewesen
###### 2233 | ### Do slvog er Wolfharten dvrch eine brvnne gvot ### daz im von der wunde nider schoz daz blvot ### er wunte zvo dem tode den Dietriches man ### ez het an einen reken zware niemen getan
###### 2234 | ### Also der chvene Wolfhart der wunden do enphant ### den schilt den liez er vallen hoher an der hant ### hvop er ein starckez wafen daz waz sharpf genvoch ### durch helm vn– dvrch ringe der helt do Giselhern slvoch
###### 2235 | ### Si heten bede an ein ander den grimmen tot getan ### do enlebt och nv niht mere der Dietriches man [91a] ### Hildebrant der alte Wolfharten vallen sach ### ich wene im vor sinem tode so rehte leide nie geschach
###### 2236 | ### Do waren gar erstorben die Gvnthers man ### vn– ovch die Dietriches Hildebrant waz gegan ### da Wolfhart waz gevallen nider in daz blvot ### er vmbesloz mit armen den reken chven vn– gvot
###### 2237 | ### Er wolt in vz dem hvse mit im tragen dan ### er waz ein teil ze swere er mvose in ligen lan ### do blichte vz dem blvote der rewude man ### er sach wol daz im gerne sin neve het geholfen dan
###### 2238 | ### Do sprach der totwunde vil lieber oehæim min ### ir mvgt an disen ziten mir niht frvm gesin ### nv hvetet ivch vor Hagene ia dvnchet ez mich gvot ### er treit in sinem herzen einen grimmigen mvot
###### 2239 | ### Vnde ob mich mine mage nach tode wellen klagen ### den nehsten vn– den besten den svlt ir von mir sagen ### daz si nach mir iht wainen daz si ane not ### vor æines chvniges hande lig ich hie herlichen tot
###### 2240 | ### Ich han ovch hier inne so vergolten minen lip ### daz ez wol mvgen bewainen der gvoten riter wip ### ob ivch dez iemen vrage so mvgt ir balde sagen ### vor min eines handen lit wol hvndert erslagen
###### 2241 | ### Do gedaht ovch Hagen an den spileman ### dem der chvene Hildebrane sin leben an gewan ### do sprach er zvo dem degene ir gelt mir miniv leit ### ir hapt vns hier inne erbvnnet vil <maniges> reken gemæit
###### 2242 | ### Er slvog vf Hildebrande daz manz wol vernam ### Palmvnge diezen den Sifride nam ### Hagen der vil chvene da er den helt slvoch ### do werte sich der alte er waz och chvene genvoch
###### 2243 | ### Der Dietriches reke slvog æin wafen bræit ### vf den helt von Tronge daz och vil sere sneit ### do en chvnde er niht verwunden den Gvnthers man ### do slvog aber in Hagen dvrh æine brvnne wolgetan
###### 2244 | ### Do der alte Hildebrant der wunden reht enphant ### do vorht er schaden mere von der Hagen hant ### den schilt warf vber rvkke der Dietriches man ### mit der starchen wunden der helt do Hagen entran
###### 2245 | ### Ia was nv nieman lebender al der degene ### niwan die zwene aleine Gvnther vn– Hagene ### mit blvote gie bervnnen der alte Hildebrant ### er brahte læidev mere da er Dietrichen vant
###### 2246 | ### Do sach er trovrichlichen sitzen hie den man ### der laide michels mere der fvrste do gewan ### er sach och Hilbrande in siner brvnne rot ### do fragter in der mere als im div sorge gebot
###### 2247 | ### Nv sagt mir maister Hildebrant wie sit ir so naz ### von dem verehblvote oder wer tet iv daz [91b] ### ich wene ir mit den zem hvse hapt gestriten ### ich verbot ez iv so sere do het irz billich vermiten
###### 2248 | ### Do sagt er sinem herren ez tet Hagene ### der slvog mir dise wunden in dem gadme ### do ich von dem reken wolde wenden dan ### mit minem lebne ich chovme dem tievel etran
| ### Do sprach der Berner vil reht ist iv geschehen ### do ir mich frivntschefte den reken horet iehen ### daz ir den fride do brache den ich in het gegeben ### het ichz niht immer schaden ir soldet fliesen daz leben
###### 2250 | ### Nv enzvrnet niht so sere min her Dietrich ### an mir vnt minen frivnden der schade ist alze rich ### wir wolden Rvedegern han getragen dan ### des wolden vns niht gvnnen des kvnich Gvntheres man
###### 2251 | ### So we mir dirre læide ist Rvedeger doch tot ### den mvoz ich immer chlagen dez get mir groziv not ### Gotelint dev edel ist miner basen chint ### ach we der arm waisen die da ze Bechelarn sint
###### 2252 | ### Iriwen vn– læides mant in do sin tot ### er begvnde wainen des dem helde not ### owe der getriwer helfe die ich verlorn han ### ia vberwinde ich nimmer mere des kvnich Ezeln man
###### 2253 | ### Megt ir mir maister Hildebrant div rehten mere sagen ### wer der reke were der in da hat erslagen ### er sprach daz tet mit chrefte der starche Gernot ### vor Rvedegeres handen ist ovch der het gelegen tot
###### 2254 | ### Er sprach ze Hildebrande nv sagt minen man ### daz sich balde waffen wan ich wil dar gan ### vn– heizet mir gewinnen min liehtez wickgewant ### ich selbe fragen die helde vz Bvrgonde lant
###### 2255 | ### Do sprach maister Hildebrant wer sol zvo iv gen ### swaz ir hapt der lebenden die seht ir bi iv sten ### daz bin ich alterseine die andern die sint tot ### do ershrichte er dirre mere des gie im werlichen not
###### 2256 | ### wan er læit so grozez zer werlde hie gewan ### er sprach vnd sint erstorben alle mine man ### so hat min got vergezzen ich armer Dietrich ### ich waz ein kvnich gewaltich her vnde rich
###### 2257 | ### Wie chvnde ez sich gefvegen sprach aber her Dietrich ### daz si alle sint erstorben die helde lobelich ### von den stritmveden die doch heten not ### wan dvrch min vngelvckhe in iwer noch frevomde der tot
###### 2258 | ### Sit daz ez min vnselde niht langer wolt entwesen ### so sagt mir ist der geste noch ieman da genesen ### do sprach maister Hildebrant daz weiz got nieman mer ### niwan Hagen alæine vn– Gvnther der chvnich her
###### 2259 | ### Owe lieber Wolfhart sol ich dich han verlorn ### so mag mich balde riwen daz ich ie wart geborn ### Svgstap vn– Wolfwin vn– och Wolbrant ### wer sol mir denne helfen in der Amelvnge lant [92a]
###### 2260 | ### Helpfrich der vil chvne vn– ist mir der erslagen ### Gerhart vn– Wichart wie solde ich die verchlagen ### daz ist an minen fveden min der leste tach ### owe daz vor leide nieman wol sterben mach

<<< Übersicht <<< vorige Seite nächste Seite >>>